==> reka-react-code-editor-0.1.4.tgz: package/CHANGELOG.md <==
# @rekajs/react-code-editor

## 0.1.4

### Patch Changes

- [`a20601e`](https://github.com/prevwong/reka.js/commit/a20601e98ce9ee962d29c5c957f063c420f2e025) Thanks [@prevwong](https://github.com/prevwong)! - Bump codemirror dependencies to stable versions

- [`61435db`](https://github.com/prevwong/reka.js/commit/61435dbfb88326eabe7857e43318a45459b08343) Thanks [@prevwong](https://github.com/prevwong)! - Inject package version to browser window

- [`4a6685f`](https://github.com/prevwong/reka.js/commit/4a6685f53f092a7b39b63be1dfa7d34bf99195bf) Thanks [@prevwong](https://github.com/prevwong)! - Minor theme styling update

- Updated dependencies [[`a20601e`](https://github.com/prevwong/reka.js/commit/a20601e98ce9ee962d29c5c957f063c420f2e025), [`61435db`](https://github.com/prevwong/reka.js/commit/61435dbfb88326eabe7857e43318a45459b08343)]:
  - @rekajs/codemirror@0.1.2

## 0.1.3

### Patch Changes

- [`b5aec26`](https://github.com/prevwong/reka.js/commit/b5aec26d55685cbc3ade66a16413ef7bf3f46e4a) Thanks [@prevwong](https://github.com/prevwong)! - Add CJS bundle

- Updated dependencies [[`b5aec26`](https://github.com/prevwong/reka.js/commit/b5aec26d55685cbc3ade66a16413ef7bf3f46e4a)]:
  - @rekajs/codemirror@0.1.1

## 0.1.2

### Patch Changes

- [`b6712fc`](https://github.com/prevwong/reka.js/commit/b6712fc9096105674d0f5d50aff437e9661c0841) Thanks [@prevwong](https://github.com/prevwong)! - Update `@rekajs/codemirror` as a required dep

## 0.1.1

### Patch Changes

- da3c4c8: fix: peer deps
- da3c4c8: fix: code editor lag

## 0.1.0

### Patch Changes

- bcdb728: - Improved APIs and better typings
  - Separate shared utils package
  - Update Lezer grammer for Codemirror Extension
- Updated dependencies [bcdb728]
  - @rekajs/codemirror@0.1.0
  - @rekajs/core@0.1.0
  - @rekajs/parser@0.1.0
  - @rekajs/react@0.1.0
  - @rekajs/types@0.1.0

==> reka-react-code-editor-0.1.5.tgz: package/CHANGELOG.md <==
# @depla/reka-react-code-editor

## 0.1.4

### Patch Changes

- [`a20601e`](https://github.com/prevwong/reka.js/commit/a20601e98ce9ee962d29c5c957f063c420f2e025) Thanks [@prevwong](https://github.com/prevwong)! - Bump codemirror dependencies to stable versions

- [`61435db`](https://github.com/prevwong/reka.js/commit/61435dbfb88326eabe7857e43318a45459b08343) Thanks [@prevwong](https://github.com/prevwong)! - Inject package version to browser window

- [`4a6685f`](https://github.com/prevwong/reka.js/commit/4a6685f53f092a7b39b63be1dfa7d34bf99195bf) Thanks [@prevwong](https://github.com/prevwong)! - Minor theme styling update

- Updated dependencies [[`a20601e`](https://github.com/prevwong/reka.js/commit/a20601e98ce9ee962d29c5c957f063c420f2e025), [`61435db`](https://github.com/prevwong/reka.js/commit/61435dbfb88326eabe7857e43318a45459b08343)]:
  - @depla/reka-codemirror@0.1.2

## 0.1.3

### Patch Changes

- [`b5aec26`](https://github.com/prevwong/reka.js/commit/b5aec26d55685cbc3ade66a16413ef7bf3f46e4a) Thanks [@prevwong](https://github.com/prevwong)! - Add CJS bundle

- Updated dependencies [[`b5aec26`](https://github.com/prevwong/reka.js/commit/b5aec26d55685cbc3ade66a16413ef7bf3f46e4a)]:
  - @depla/reka-codemirror@0.1.1

## 0.1.2

### Patch Changes

- [`b6712fc`](https://github.com/prevwong/reka.js/commit/b6712fc9096105674d0f5d50aff437e9661c0841) Thanks [@prevwong](https://github.com/prevwong)! - Update `@depla/reka-codemirror` as a required dep

## 0.1.1

### Patch Changes

- da3c4c8: fix: peer deps
- da3c4c8: fix: code editor lag

## 0.1.0

### Patch Changes

- bcdb728: - Improved APIs and better typings
  - Separate shared utils package
  - Update Lezer grammer for Codemirror Extension
- Updated dependencies [bcdb728]
  - @depla/reka-codemirror@0.1.0
  - @depla/reka-core@0.1.0
  - @depla/reka-parser@0.1.0
  - @depla/reka-react@0.1.0
  - @depla/reka-types@0.1.0
